# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

import socket

from werkzeug.serving import make_server
import threading
import webbrowser
import pyqrcode
import platform
from htf.core import BrowserInteraction
from htf.termcolors import info


class BrowserInteractionServer(threading.Thread):
    def __init__(self, app, host="0.0.0.0", port=8080, url="/"):
        threading.Thread.__init__(self)
        self.server = make_server(host, port, app, threaded=True)
        self.context = app.app_context()
        self.context.push()
        hostname = socket.gethostname()
        full_url = "http://{}:{}{}".format(hostname, port, url)

        if full_url.lower().endswith("/index.html"):
            full_url = full_url[:-11]

        if full_url.lower().endswith("/"):
            full_url = full_url[:-1]

        print(info("Running an interactive session on {}".format(full_url)))
        qrcode = pyqrcode.create(full_url)

        if platform.system() == "Windows":
            # Windows
            print(qrcode.terminal(module_color='black', background='white', quiet_zone=1))
        else:
            # Linux, etc.
            print(qrcode.terminal(quiet_zone=1))
        
        webbrowser.open(full_url)

    def run(self):
        self.server.serve_forever()

    def shutdown(self):
        self.server.shutdown()


def BrowserInteractionFixture(data_directory=None, host="0.0.0.0", port=8080, url="/"):
    interaction = BrowserInteraction(__name__)

    if data_directory is not None:
        interaction.set_data_directory(data_directory)

    server = BrowserInteractionServer(interaction, host=host, port=port, url=url)
    server.start()
    yield interaction
    server.shutdown()
