# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

import re


def regex_validator(pattern, exception_message=None):
    """
    A regex validator factory.

    Args:
        pattern (str): the regex pattern to be checked
        exception_message=None (str): the optional exception message supplied to the user in its browser

    Returns:
        an interaction validator for pattern
    """
    def validator(text):
        if not re.match(pattern, text):
            if exception_message is not None:
                raise Exception(exception_message)
            else:
                raise Exception("Input does not match required pattern '{}'".format(pattern))
        return text

    return validator


def int_validator(value):
    """
    An int validator for interactive tests.
    """
    try:
        return int(value)
    except Exception:
        raise Exception('Input must be an integer value.')


def float_validator(value):
    """
    A float validator for interactive tests.
    """
    try:
        return float(value)
    except Exception:
        raise Exception('Input must be a float value.')