# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#
from htf.core import dryrun as _dryrun
from htf.core import get_choices as _get_choices
from htf.core import get_tags as _get_tags
from htf.core import get_statements as _get_statements
from htf.core import main as _main
from htf.core import module_list as _module_list
from htf.core import run as _run


def dryrun(title='Testreport', tests='__main__', tags=None, fixture_tags=None, html_report=None, junit_xml_report=None, json_report=None, yaml_report=None, report_server=None, extra_report=None, create_drafts=False, open_report=False, pattern='test*.py', metadata=None, parameters=None, exit=True, failfast=None, minimize_report_size=False, interactive=False, interactive_address='0.0.0.0', interactive_port=8080, shuffle=False, shuffle_seed=None):
    """
    Test runner for a dry run to watch the test suite.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        ags=None (str): test filter expression
        fixture_tags=None (str): fixture filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False (bool): if set to ``True`` draft reports are created after each test
        open_report=False (bool): if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        parameters=None (dict): a dictionary that contains parameters for the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.
        interactive=False (bool): if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0" (str): the ip address the interaction server listens on.
        interactive_port=8080 (int): the port the interaction server listens on.
        shuffle=False (bool): set to ``True`` to shuffle tests
        shuffle_seed=None (str): the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _dryrun(title=title, tests=tests, tags=tags, fixture_tags=fixture_tags, html_report=html_report, junit_xml_report=junit_xml_report, json_report=json_report, yaml_report=yaml_report, report_server=report_server, extra_report=extra_report, create_drafts=create_drafts, open_report=open_report, pattern=pattern, metadata=metadata, parameters=parameters, exit=exit, failfast=failfast, minimize_report_size=minimize_report_size, interactive=interactive, interactive_address=interactive_address, interactive_port=interactive_port, shuffle=shuffle, shuffle_seed=shuffle_seed)


def get_choices(part):
    """
    Return a list of strings
    that describe importable python
    modules and its contents.
    Eg.:
    - tests.test_1
    - tests
    - tests.test_1.TestCase
    - tests.test_1.TestCase.test_method

    Case 1) complete or incomplete root module -> list all root
        modules starting with part
    Case 2) complete root module + "." -> list all sub-modules and entries
    Case 3) complete root module + ".<part>" -> list all sub-modules
        and entries starting with part and
    """
    return _get_choices(part=part)


def get_tags(tests='__main__', pattern='test*.py'):
    """
    Get a list of tags found in the specified tests.

    Args:
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders

    Returns:
        list of str: a list of tags found in the specified tests.
    """
    return _get_tags(tests=tests, pattern=pattern)


def get_statements(tests='__main__'):
    """
    Get a dict of behavior driven development statements found in the specified tests.

    Args:
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)

    Returns:
        dict: a dict with all behavior driven development statements found
    """
    return _get_statements(tests=tests)


def main(title='Testreport', tests='__main__', tags=None, fixture_tags=None, html_report=None, junit_xml_report=None, json_report=None, yaml_report=None, report_server=None, extra_report=None, create_drafts=False, open_report=False, pattern='test*.py', metadata=None, parameters=None, exit=True, failfast=None, minimize_report_size=False, interactive=False, interactive_address='0.0.0.0', interactive_port=8080, shuffle=False, shuffle_seed=None):
    """
    Test runner.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None (str): test filter expression
        fixture_tags=None (str): fixture filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False (bool): if set to ``True`` draft reports are created after each test
        open_report=False (bool): if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        parameters=None (dict): a dictionary that contains parameters for the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.
        interactive=False (bool): if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0" (str): the ip address the interaction server listens on.
        interactive_port=8080 (int): the port the interaction server listens on.
        shuffle=False (bool): set to ``True`` to shuffle tests
        shuffle_seed=None (str): the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _main(title=title, tests=tests, tags=tags, fixture_tags=fixture_tags, html_report=html_report, junit_xml_report=junit_xml_report, json_report=json_report, yaml_report=yaml_report, report_server=report_server, extra_report=extra_report, create_drafts=create_drafts, open_report=open_report, pattern=pattern, metadata=metadata, parameters=parameters, exit=exit, failfast=failfast, minimize_report_size=minimize_report_size, interactive=interactive, interactive_address=interactive_address, interactive_port=interactive_port, shuffle=shuffle, shuffle_seed=shuffle_seed)


def module_list(path):
    """
    Return the list containing the names of the modules available in the given
    folder.
    """
    return _module_list(path=path)


def run(title='Testreport', tests='__main__', tags=None, fixture_tags=None, html_report=None, junit_xml_report=None, json_report=None, yaml_report=None, report_server=None, extra_report=None, create_drafts=False, open_report=False, pattern='test*.py', metadata=None, parameters=None, exit=True, failfast=None, minimize_report_size=False, interactive=False, interactive_address='0.0.0.0', interactive_port=8080, shuffle=False, shuffle_seed=None):
    """
    Test runner.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None (str): test filter expression
        fixture_tags=None (str): fixture filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False (bool): if set to ``True`` draft reports are created after each test
        open_report=False (bool): if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        parameters=None (dict): a dictionary that contains parameters for the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.
        interactive=False (bool): if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0" (str): the ip address the interaction server listens on.
        interactive_port=8080 (int): the port the interaction server listens on.
        shuffle=False (bool): set to ``True`` to shuffle tests
        shuffle_seed=None (str): the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _run(title=title, tests=tests, tags=tags, fixture_tags=fixture_tags, html_report=html_report, junit_xml_report=junit_xml_report, json_report=json_report, yaml_report=yaml_report, report_server=report_server, extra_report=extra_report, create_drafts=create_drafts, open_report=open_report, pattern=pattern, metadata=metadata, parameters=parameters, exit=exit, failfast=failfast, minimize_report_size=minimize_report_size, interactive=interactive, interactive_address=interactive_address, interactive_port=interactive_port, shuffle=shuffle, shuffle_seed=shuffle_seed)


