# -*- coding: utf-8 -*-
#
# Copyright (c) 2022, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

from htf.environment import get_current_environment
from functools import wraps


def metadata(**metadata):
    """
    Provides a way to set metadata in the test report for the decorated function.

    Args:
        metadata: the dictionary of metadata
    """

    def wrapper(wrapped):
        @wraps(wrapped)
        def _metadata(*args, **kwargs):
            environment = get_current_environment()
            fixture_metadata = environment.get_fixture("metadata")
            for k, v in metadata.items():
                fixture_metadata.set(k, v)

            wrapped(*args, **kwargs)
        return _metadata

    return wrapper
