# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
from functools import wraps

from htf.core import TestRunner as _TestRunner
from htf.core import DryRunner as _DryRunner


class TestRunner(_TestRunner):

    def __init__(self, test_suite, environment, evaluation):
        """
        Initialize self.  See help(type(self)) for accurate signature.
        """
        super(TestRunner, self).__init__(test_suite=test_suite, environment=environment, evaluation=evaluation)

    def run(self):
        return super(TestRunner, self).run()

    def _wrap_test(self, instance, test):
        """
        Wrapper for legacy tests inheriting from htf.TestCase.
        Necessary to ensure setUp(), afterTest() and tearDown() are called.

        Args:
            instance (htf.TestCase): test case instance
            test (method): test method

        Returns:
            wrapped test function
        """
        @wraps(test)
        def wrapper(*args, **kwargs):
            try:
                instance.setUp()
                test(*args, **kwargs)
            finally:
                instance.tearDown()

        return wrapper


class DryRunner(_DryRunner):

    def __init__(self, test_suite, environment, evaluation):
        """
        Initialize self.  See help(type(self)) for accurate signature.
        """
        super(DryRunner, self).__init__(test_suite=test_suite, environment=environment, evaluation=evaluation)

    def run(self):
        return super(DryRunner, self).run()

