# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#
from htf.core import TestCase as _TestCase


class TestCase(_TestCase):
    """
    ``TestCase`` is the basic test case class for the HILSTER Testing Framework
    that should be used using inheritance.
    """

    def __init__(self, method_name='run_test'):
        """
        Args:
            method_name='run_test' (str): the name of the test method to be
                run by the test runner.
        """
        super(TestCase, self).__init__(method_name=method_name)

    @staticmethod
    def assertAlmostEqual(first, second, places=None, msg=None, delta=None):
        """
        Assert that ``a`` and ``b`` are almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            first (float): number
            second (float): number
            places=None (int): the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None (float): the maximum delta
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not almost equal.
        """
        return _TestCase.assertAlmostEqual(first=first, second=second, places=places, msg=msg, delta=delta)

    @staticmethod
    def assertDictEqual(d1, d2, msg=None):
        """
        Assert that ``d1`` equals ``d2`` and that both are of type ``dict``.

        Args:
            d1: a dict
            d2: a dict
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``d1`` and ``d2`` are not equal.
        """
        return _TestCase.assertDictEqual(d1=d1, d2=d2, msg=msg)

    @staticmethod
    def assertEqual(first, second, msg=None):
        """
        Assert that ``a`` equals ``b``. Tries to find a registered equality asserter and uses the base assert if
        no special assert is registered.

        Args:
            first: an object
            second: an object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assertEqual(first=first, second=second, msg=msg)

    @staticmethod
    def assertFalse(expr, msg=None):
        """
        Assert that ``expression`` is ``False``.

        Args:
            expr (bool): the boolean expression to be validated
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``False``
        """
        return _TestCase.assertFalse(expr=expr, msg=msg)

    @staticmethod
    def assertGreater(a, b, msg=None):
        """
        Assert that ``a`` is greater than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater than ``b``
        """
        return _TestCase.assertGreater(a=a, b=b, msg=msg)

    @staticmethod
    def assertGreaterEqual(a, b, msg=None):
        """
        Assert that ``a`` is greater or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater or equal to ``b``
        """
        return _TestCase.assertGreaterEqual(a=a, b=b, msg=msg)

    @staticmethod
    def assertIn(member, container, msg=None):
        """
        Assert that ``container`` contains ``member``.

        Args:
            member: the object that shall be included in ``container``
            container (iterable): an iterable to search for ``member``
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is not included in ``container``
        """
        return _TestCase.assertIn(member=member, container=container, msg=msg)

    @staticmethod
    def assertIs(expr1, expr2, msg=None):
        """
        Assert that ``id(expr1)`` equals ``id(expr2)``.

        Args:
            expr1: an object
            expr2: another object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``id(expr1)`` does not equal ``id(expr2)``
        """
        return _TestCase.assertIs(expr1=expr1, expr2=expr2, msg=msg)

    @staticmethod
    def assertIsInstance(obj, cls, msg=None):
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assertIsInstance(obj=obj, cls=cls, msg=msg)

    @staticmethod
    def assertIsNone(obj, msg=None):
        """
        Assert that ``obj`` is ``None``.

        Args:
            obj: an object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not ``None``
        """
        return _TestCase.assertIsNone(obj=obj, msg=msg)

    @staticmethod
    def assertIsNot(expr1, expr2, msg=None):
        """
        Assert that ``id(expr1)`` does not equal ``id(expr2)``.

        Args:
            expr1: an object
            expr2: another object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``id(expr1)`` equals ``id(expr2)``
        """
        return _TestCase.assertIsNot(expr1=expr1, expr2=expr2, msg=msg)

    @staticmethod
    def assertIsNotNone(obj, msg=None):
        """
        Assert that ``obj`` is not ``None``.

        Args:
            obj: an object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is  ``None``
        """
        return _TestCase.assertIsNotNone(obj=obj, msg=msg)

    @staticmethod
    def assertLess(a, b, msg=None):
        """
        Assert that ``a`` is less than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less than ``b``
        """
        return _TestCase.assertLess(a=a, b=b, msg=msg)

    @staticmethod
    def assertLessEqual(a, b, msg=None):
        """
        Assert that ``a`` is less or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less or equal to ``b``
        """
        return _TestCase.assertLessEqual(a=a, b=b, msg=msg)

    @staticmethod
    def assertListEqual(list1, list2, msg=None):
        """
        Assert that ``list1`` equals ``list2`` and that both are of type ``list``.

        Args:
            list1: a list
            list2: a list
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assertListEqual(list1=list1, list2=list2, msg=msg)

    @staticmethod
    def assertMultiLineEqual(first, second, msg=None):
        """
        Assert that ``first`` equals ``second`` and that both are of type ``str``.

        Args:
            first: a string
            second: a string
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``first`` and ``second`` are not equal.
        """
        return _TestCase.assertMultiLineEqual(first=first, second=second, msg=msg)

    @staticmethod
    def assertNotAlmostEqual(first, second, places=None, msg=None, delta=None):
        """
        Assert that ``a`` and ``b`` are not almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            first (float): number
            second (float): number
            places=None (int): the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None (float): the maximum delta
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are almost equal.
        """
        return _TestCase.assertNotAlmostEqual(first=first, second=second, places=places, msg=msg, delta=delta)

    @staticmethod
    def assertNotEqual(first, second, msg=None):
        """
        Assert that ``a`` does not equal ``b``.

        Args:
            first: an object
            second: an object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are equal.
        """
        return _TestCase.assertNotEqual(first=first, second=second, msg=msg)

    @staticmethod
    def assertNotIn(member, container, msg=None):
        """
        Assert that ``container`` does not contain ``member``.

        Args:
            member: the object that shall not be included in ``container``
            container (iterable): an iterable to search for ``member``
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is included in ``container``
        """
        return _TestCase.assertNotIn(member=member, container=container, msg=msg)

    @staticmethod
    def assertNotIsInstance(obj, cls, msg=None):
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assertNotIsInstance(obj=obj, cls=cls, msg=msg)

    @staticmethod
    def assertNotRegex(text, unexpected_regex, msg=None):
        """
        Assert that ``text`` does not match regular expression ``unexpected_regex``.

        Args:
            text: a text to be matched
            unexpected_regex: a regular expression to be used
            message=None (str): the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` matches regular expression ``unexpected_regex``.
        """
        return _TestCase.assertNotRegex(text=text, unexpected_regex=unexpected_regex, msg=msg)

    @staticmethod
    def assertRaises(expected_exception, callable_object=None, *args, **kwargs):
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception (type): the expected exception that shall be raised
            callable_object=None (callable): the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assertRaises(expected_exception, callable_object, *args, **kwargs)

    @staticmethod
    def assertRaisesRegex(expected_exception, expected_regex, callable_object=None, *args, **kwargs):
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception (type): the expected exception that shall be raised
            expected_regex (regular expression): the regular expression that shall match the stringified representation
                of the exception
            callable_object=None (callable): the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assertRaisesRegex(expected_exception, expected_regex, callable_object, *args, **kwargs)

    @staticmethod
    def assertRegex(text, expected_regex, msg=None):
        """
        Assert that ``text`` matches regular expression ``expected_regex``.

        Args:
            text: a text to be matched
            expected_regex: a regular expression to be used
            message=None (str): the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` does not match regular expression ``expected_regex``.
        """
        return _TestCase.assertRegex(text=text, expected_regex=expected_regex, msg=msg)

    @staticmethod
    def assertSequenceEqual(seq1, seq2, msg=None, seq_type=None):
        """
        Assert that ``seq1`` equals ``seq2`` and that both are sequences.

        Args:
            seq1: a sequence
            seq2: a sequence
            msg=None (str): the message to prepend to the error message
            seq_type=None (type): the sequence type to be used (if not ``None``)

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assertSequenceEqual(seq1=seq1, seq2=seq2, msg=msg, seq_type=seq_type)

    @staticmethod
    def assertSetEqual(set1, set2, msg=None):
        """
        Assert that ``set1`` equals ``set2`` and that both are of type ``set``.

        Args:
            set1: a set
            set2: a set
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``set1`` and ``set2`` are not equal.
        """
        return _TestCase.assertSetEqual(set1=set1, set2=set2, msg=msg)

    @staticmethod
    def assertTrue(expr, msg=None):
        """
        Assert that ``expression`` is ``True``.

        Args:
            expr (bool): the boolean expression to be validated
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``True``
        """
        return _TestCase.assertTrue(expr=expr, msg=msg)

    @staticmethod
    def assertTupleEqual(tuple1, tuple2, msg=None):
        """
        Assert that ``tuple1`` equals ``tuple2`` and that both are of type ``tuple``.

        Args:
            tuple1: a list
            tuple2: a list
            msg=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assertTupleEqual(tuple1=tuple1, tuple2=tuple2, msg=msg)

    @staticmethod
    def assert_almost_equal(a, b, places=None, delta=None, message=None):
        """
        Assert that ``a`` and ``b`` are almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            a (float): number
            b (float): number
            places=None (int): the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None (float): the maximum delta
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not almost equal.
        """
        return _TestCase.assert_almost_equal(a=a, b=b, places=places, delta=delta, message=message)

    @staticmethod
    def assert_dict_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``dict``.

        Args:
            a: a dict
            b: a dict
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_dict_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b``. Tries to find a registered equality asserter and uses the base assert if
        no special assert is registered.

        Args:
            a: an object
            b: an object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_false(expression, message=None):
        """
        Assert that ``expression`` is ``False``.

        Args:
            expression (bool): the boolean expression to be validated
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``False``
        """
        return _TestCase.assert_false(expression=expression, message=message)

    @staticmethod
    def assert_greater(a, b, message=None):
        """
        Assert that ``a`` is greater than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater than ``b``
        """
        return _TestCase.assert_greater(a=a, b=b, message=message)

    @staticmethod
    def assert_greater_equal(a, b, message=None):
        """
        Assert that ``a`` is greater or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater or equal to ``b``
        """
        return _TestCase.assert_greater_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_in(member, container, message=None):
        """
        Assert that ``container`` contains ``member``.

        Args:
            member: the object that shall be included in ``container``
            container (iterable): an iterable to search for ``member``
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is not included in ``container``
        """
        return _TestCase.assert_in(member=member, container=container, message=message)

    @staticmethod
    def assert_is(a, b, message=None):
        """
        Assert that ``id(a)`` equals ``id(b)``.

        Args:
            a: an object
            b: another object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``id(a)`` does not equal ``id(b)``
        """
        return _TestCase.assert_is(a=a, b=b, message=message)

    @staticmethod
    def assert_is_instance(obj, cls, message=None):
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assert_is_instance(obj=obj, cls=cls, message=message)

    @staticmethod
    def assert_is_none(obj, message=None):
        """
        Assert that ``obj`` is ``None``.

        Args:
            obj: an object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not ``None``
        """
        return _TestCase.assert_is_none(obj=obj, message=message)

    @staticmethod
    def assert_is_not(a, b, message=None):
        """
        Assert that ``id(a)`` does not equal ``id(b)``.

        Args:
            a: an object
            b: another object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``id(a)`` equals ``id(b)``
        """
        return _TestCase.assert_is_not(a=a, b=b, message=message)

    @staticmethod
    def assert_is_not_none(obj, message=None):
        """
        Assert that ``obj`` is not ``None``.

        Args:
            obj: an object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is  ``None``
        """
        return _TestCase.assert_is_not_none(obj=obj, message=message)

    @staticmethod
    def assert_less(a, b, message=None):
        """
        Assert that ``a`` is less than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less than ``b``
        """
        return _TestCase.assert_less(a=a, b=b, message=message)

    @staticmethod
    def assert_less_equal(a, b, message=None):
        """
        Assert that ``a`` is less or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less or equal to ``b``
        """
        return _TestCase.assert_less_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_list_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``list``.

        Args:
            a: a list
            b: a list
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_list_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_multi_line_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``str``.

        Args:
            a: a string
            b: a string
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_multi_line_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_not_almost_equal(a, b, places=None, delta=None, message=None):
        """
        Assert that ``a`` and ``b`` are not almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            a (float): number
            b (float): number
            places=None (int): the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None (float): the maximum delta
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are almost equal.
        """
        return _TestCase.assert_not_almost_equal(a=a, b=b, places=places, delta=delta, message=message)

    @staticmethod
    def assert_not_equal(a, b, message=None):
        """
        Assert that ``a`` does not equal ``b``.

        Args:
            a: an object
            b: an object
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are equal.
        """
        return _TestCase.assert_not_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_not_in(member, container, message=None):
        """
        Assert that ``container`` does not contain ``member``.

        Args:
            member: the object that shall not be included in ``container``
            container (iterable): an iterable to search for ``member``
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is included in ``container``
        """
        return _TestCase.assert_not_in(member=member, container=container, message=message)

    @staticmethod
    def assert_not_is_instance(obj, cls, message=None):
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assert_not_is_instance(obj=obj, cls=cls, message=message)

    assert_is_not_instance = assert_not_is_instance

    @staticmethod
    def assert_not_regex(text, unexpected_regex, message=None):
        """
        Assert that ``text`` does not match regular expression ``unexpected_regex``.

        Args:
            text: a text to be matched
            unexpected_regex: a regular expression to be used
            message=None (str): the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` matches regular expression ``unexpected_regex``.
        """
        return _TestCase.assert_not_regex(text=text, unexpected_regex=unexpected_regex, message=message)

    @staticmethod
    def assert_raises(expected_exception, callable_object=None, *args, **kwargs):
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception (type): the expected exception that shall be raised
            callable_object=None (callable): the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assert_raises(expected_exception, callable_object, *args, **kwargs)

    @staticmethod
    def assert_raises_regex(expected_exception, expected_regex, callable_object=None, *args, **kwargs):
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception (type): the expected exception that shall be raised
            expected_regex (regular expression): the regular expression that shall match the stringified representation
                of the exception
            callable_object=None (callable): the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assert_raises_regex(expected_exception, expected_regex, callable_object, *args, **kwargs)

    @staticmethod
    def assert_regex(text, expected_regex, message=None):
        """
        Assert that ``text`` matches regular expression ``expected_regex``.

        Args:
            text: a text to be matched
            expected_regex: a regular expression to be used
            message=None (str): the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` does not match regular expression ``expected_regex``.
        """
        return _TestCase.assert_regex(text=text, expected_regex=expected_regex, message=message)

    @staticmethod
    def assert_sequence_equal(a, b, message=None, sequence_type=None):
        """
        Assert that ``a`` equals ``b`` and that both are sequences.

        Args:
            a: a sequence
            b: a sequence
            sequence_type=None (type): the sequence type to be used (if not ``None``)
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_sequence_equal(a=a, b=b, message=message, sequence_type=sequence_type)

    @staticmethod
    def assert_set_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``set``.

        Args:
            a: a set
            b: a set
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_set_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_str_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``str``.

        Args:
            a: a string
            b: a string
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_str_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_true(expression, message=None):
        """
        Assert that ``expression`` is ``True``.

        Args:
            expression (bool): the boolean expression to be validated
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``True``
        """
        return _TestCase.assert_true(expression=expression, message=message)

    @staticmethod
    def assert_tuple_equal(a, b, message=None):
        """
        Assert that ``a`` equals ``b`` and that both are of type ``tuple``.

        Args:
            a: a list
            b: a list
            message=None (str): the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_tuple_equal(a=a, b=b, message=message)

    def attach_file(self, filename, title):
        """
        Attach a file to the current test that is put into
        the test report.

        Args:
            filename (str): the filename to be attached
            title (str): the title
        """
        return super(TestCase, self).attach_file(filename=filename, title=title)

    attachFile = attach_file

    def attach_url(self, url, title):
        """
        Attach an url to the current test that is put into the test report.
        This results in an external link and should be used for huge files.

        Args:
            url (str): the url to be attached
            title (str): the title
        """
        return super(TestCase, self).attach_url(url=url, title=title)

    attachUrl = attach_url

    def delay(self, duration):
        """
        Delay execution for a given duration and print progress.

        Args:
            duration (float): sleep duration
        """
        return super(TestCase, self).delay(duration=duration)

    sleep = delay

    def expect(self, expected_value, observed_value, error_message=None):
        """
        Expect that ``expectedValue`` and ``observedValue`` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            expected_value: the expected value.
            observed_value: the observed value that is compared to
                ``expectedValue``.
            errorMessage=None (str): an optional message.
        """
        return super(TestCase, self).expect(expected_value=expected_value, observed_value=observed_value, error_message=error_message)

    def expect_step(self, title, expected_value, observed_value, error_message=None):
        """
        Creates a test step in test report and on stdout using ``title``.
        Expect that `expectedValue` and `observedValue` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            title (str): the step's title.
            expected_value: the value that is expected.
            observed_value: the current observed value that is compared to
                ``expectedValue``.
            errorMessage=None (str): an optional message.
        """
        return super(TestCase, self).expect_step(title=title, expected_value=expected_value, observed_value=observed_value, error_message=error_message)

    expectStep = expect_step

    def run_background(self, func, name=None, stop=None, force_stop=True, join_timeout=1, args=None, kwargs=None):
        """
        With this method you can run another method in background.

        Args:
            func (callable): the method to be run in background.
            name=None (str): a name for the background task.
                Default: ``None``. If `name` is ``None`` `func.__name__` is
                used.
            stop=None (callable): callable to stop the thread
            force_stop=True (bool): force the thread to stop when leaving its scope (can impact performance)
            join_timeout=1 (float): the timeout to be used when calling ``join``
                on the thread.
            args=None (tuple): a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None (dict): a dictionary of keyword arguments that are
                passed to the background task when it is called.

        Returns:
            stop-trigger (callable): a callable object is returned that stops
                execution when called.
        """
        return super(TestCase, self).run_background(func=func, name=name, stop=stop, force_stop=force_stop, join_timeout=join_timeout, args=args, kwargs=kwargs)

    runBackground = run_background

    def run_periodic(self, func, period, maximum_period=None, name=None, raise_exception=True, args=None, kwargs=None):
        """
        With this method you can run another method periodically
        in background with a given period.

        Args:
            func (callable): the method to be called periodically in
                background.
            period (float): the period in second.
            maximum_period=None (float): if set to a float >= ``period``
                ``func`` may take up to ``maximum_period`` time without
                raising an exception. A warning is printed out to stdout
                instead.
            name=None (str): a name for the background task.
            raise_exceptions=True: if set to ``True`` exceptions are put into
                the exception queue to let a test fail if a background thread
                fails.
            args=None (tuple): a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None (dict): a dictionary of keyword arguments that are
                passed to the background task when it is called.

        Returns:
            stop-trigger (callable): a callable object is returned that stops
                execution when called.
        """
        return super(TestCase, self).run_periodic(func=func, period=period, maximum_period=maximum_period, name=name, raise_exception=raise_exception, args=args, kwargs=kwargs)

    runPeriodic = run_periodic

    def setUp(self):
        """
        This method is called from test runner before a test is executed to
        create the test-fixtures.
        """
        return super(TestCase, self).setUp()

    @classmethod
    def setUpClass(cls):
        """
        This method is called for each class instance.
        """
        return super(TestCase, cls).setUpClass()

    def set_metadata(self, name, value):
        """
        Set metadata for a running test.

        Args:
            name (str): the name of the metadata
            value (str): the value of the metadata
                (``value`` is casted to a string automatically)

        Raises:
            AssertionError: if ``name`` was already set to non accidently overwrite
                existing metdata
        """
        return super(TestCase, self).set_metadata(name=name, value=value)

    setMetadata = set_metadata

    def set_output_capture_enable(self, enabled=True):
        """
        Enables or disables capturing of stdout and stderr for later
        use in test reports.

        Args:
            enabled=True (bool): the new enabled state
        """
        return super(TestCase, self).set_output_capture_enable(enabled=enabled)

    setOutputCaptureEnable = set_output_capture_enable

    def skip_step(self, message):
        """
        Skip the current test step.
        """
        return super(TestCase, self).skip_step(message=message)

    skipStep = skip_step

    def skip_test(self, message):
        """
        Skip the current test.
        """
        return super(TestCase, self).skip_test(message=message)

    skipTest = skip_test

    def step(self, title, *args, **kwargs):
        """
        Run a test step that is documented in the test report.

        Args:
            title (str): the step's title.
            *args: a tuple of positional arguments for the step's
                context.
            **kwargs: a dictionary of keyword arguments for the step's
                context.
        """
        return super(TestCase, self).step(title, *args, **kwargs)

    def stop_thread(self, name_or_function):
        """
        This method stops a specific thread with the name or
        function described by ``name_or_function`` by calling
        :func:`~htf.Thread.join` with join timeout supplied
        by :func:`~htf.fixtures.threads.run_periodic` or
        :func:`~htf.fixtures.threads.run_background` or on it.
        It does not set a stop condition so the thread must end and must
        not include an endless loop.
        If the thread is still alive after the first join messages are
        printed to inform the user.

        Args:
            name_or_function (str, callable): the name or the function
                (reference) of the thread to be stopped.

        Returns:
            int: the number of stopped threads.

        Raises:
            Exception: if the thread was not found
        """
        return super(TestCase, self).stop_thread(name_or_function=name_or_function)

    stopThread = stop_thread

    def tearDown(self):
        """
        This method is called from test runner after a test was executed
        regardless of it's result.

        This method shall destroy all used fixtures.
        """
        return super(TestCase, self).tearDown()

    @classmethod
    def tearDownClass(cls):
        """
        This method is called for each class instance.
        """
        return super(TestCase, cls).tearDownClass()


